@@ -531,6 +531,8 @@ int Blop::getSpezConst(int vnr) const {
        return mRechterSpieler ? 2 : 1;
      case spezconst_players:
        return ld->mSpielerZahl;
+     case spezconst_exploding:
+       return mAmPlatzen;
   };
 
   /* Nicht selbst bearbeitet? Dann nach oben weitergeben. */
