@@ -48,19 +48,21 @@
 #define spezvar_out2 6
 #define spezvar_kind_beim_letzten_draw_aufruf 7
 #define spezvar_anz 8
-/* spezvar_namen[] in Zustand.cpp definiert. Es enthlt auch
+/* spezvar_namen[] in knoten.cpp definiert. Es enthlt auch
    die Namen der spezconst */
 
 /* Var-Nummern von speziellen Konstanten */
-#define spezconst_anz 8
-#define spezconst_turn -1
-#define spezconst_connect -2
-#define spezconst_falling -3
-#define spezconst_size -4
-#define spezconst_loc_x -5
-#define spezconst_loc_y -6
-#define spezconst_loc_p -7
-#define spezconst_players -8
+#define spezconst_turn (-1)
+#define spezconst_connect (-2)
+#define spezconst_falling (-3)
+#define spezconst_size (-4)
+#define spezconst_loc_x (-5)
+#define spezconst_loc_y (-6)
+#define spezconst_loc_p (-7)
+#define spezconst_players (-8)
+#define spezconst_falling_fast (-9)
+#define spezconst_exploding (-10)
+#define spezconst_anz 10
 
 /* Nur zur bergabe in getSpezConst() vom Blop an den Fall-Besitzer.
    Wird zu spezconst dazugezhlt, um mitzuteilen, dass ich Blop Nr. 1
