@@ -15,5 +15,21 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "cuyointl.h"
 #include "blopbesitzer.h"
+#include "blop.h"
+#include "fehler.h"
+
+/** Liefert - bei Blopgittern - den Blop an der entsprechenden
+    Koordinate. Darf sonst nicht aufgerufen werden. Darf auch
+    nicht mit falschen Koordinaten aufgerufen werden. Wird bentigt
+    bei Variablen mit relativen Koordinaten. */
+const Blop & BlopBesitzer::getFeld(int /*x*/, int /*y*/) const {
+  throw iFehler(_("Internal error in const BlopBesitzer::getFeld()"));
+}
+
+/** Dito */
+Blop & BlopBesitzer::getFeld(int /*x*/, int /*y*/) {
+  throw iFehler(_("Internal error in BlopBesitzer::getFeld()"));
+}
 
