@@ -795,7 +795,8 @@ bool Cuyo::startLevel() {
     s.sprintf(_("Score: %d\n\nLoading Level %d...\n\n"),
 	      mPunkte[i], mLevelNr);
     mSpielfeld[i]->setText(s);
-    /* Das false besagt: Nicht erst Lschen */
+    /* Damit das nicht erst im nchsten Maineventloop gemalt wird:
+       (Das false besagt: Nicht erst Lschen) */
     mSpielfeld[i]->repaint(0, 0,
               mSpielfeld[i]->width(), mSpielfeld[i]->height(), false);
   }
@@ -902,7 +903,8 @@ Spielfeld * Cuyo::getSpielfeld(bool reSp) {
 
 /** Liefert zurck, ob die Zeit fr Grafik grade reicht */
 bool Cuyo::getInTime() const {
-  return mInTime;
+  //return mInTime;
+  return true;
 }
 
 
