@@ -88,7 +88,7 @@ class Cuyo : public QWidget {
   /** liefert true, wenn das Spiel gepaust ist. */
   bool spielPause() { return mGModus == gmodus_pause; }
   /** Liefert die Anzahl der Mitspieler zurck. */
-  bool getSpielerZahl() const;
+  int getSpielerZahl() const;
 
 
   /***** Debug-Variablen *****/
@@ -106,6 +106,9 @@ class Cuyo : public QWidget {
       (Etwas provisorisch public) */
   Bilddatei * mPauseBild;
 
+  /** Die Titelmusik, halt. (Wird dem title-Level entnommen) */
+  __String mTitelMusik;
+
 
  protected: // Private attributes
 
