@@ -19,6 +19,7 @@
 #include "spielfeld.h"
 #include "aufnahme.h"
 #include "fehler.h"
+#include "sound.h"
 
 
 /* Anzahl der Pixel: Verschiebung einen Blops beim drehen... */
@@ -46,7 +47,7 @@
 
 
 /** Konstruktor... */
-Fall::Fall(Spielfeld * sp, bool re): mSp(sp) {
+Fall::Fall(Spielfeld * sp, bool re): mRechterSpieler(re), mSp(sp) {
   mBlop[0].setBesitzer(this, re, 0);
   mBlop[1].setBesitzer(this, re, 1);
 }
@@ -140,6 +141,9 @@ void Fall::spielSchritt() {
   }
  	
   /* OK, wir kommen irgendwo auf. */
+
+  gSound->playSample(mRechterSpieler, sample_land);
+
  	
   /* Einzelblop? */
   if (mPos.r == richtung_einzel) {
@@ -442,6 +446,8 @@ int Fall::getSpezConst(int vnr) const {
     return "021"[mExtraDreh] - '0';
   case spezconst_falling:
     return 1;
+  case spezconst_falling_fast:
+    return mSchnell;
   };
 
   /* Wir wissen von nix; Blop::getSpezConst() soll den Default-Wert
