@@ -87,6 +87,8 @@ class Fall: public BlopBesitzer {
   FallPos mPos;
 
  private:
+  /** True, wenn rechter Spieler (fr Sound ntig) */
+  bool mRechterSpieler;
   /** Schnell fallen? */
   bool mSchnell;
   /** Ist es noch nicht ganz fertiggedreht? */
