@@ -13,31 +13,67 @@
 #include <qglobal.h>
 
 
-#if QT_VERSION >= 200
-#define __ColorOnly Qt::ColorOnly
-#define __lightGray Qt::lightGray
-#define __white Qt::white
-#define __black Qt::black
-//#define __char(c) c.latin1()
-#define __String QCString
+
+#if QT_VERSION < 200
+#define QT_V1 1
 #else
-#define __ColorOnly ColorOnly
-#define __lightGray lightGray
-#define __white white
-#define __black black
-//#define __char(c) c
-#define __String QString
+#define QT_V1 0
 #endif
 
-/* Ob das folgende die beste Lsung fr Windows ist, wei ich nicht.
-   Aber es ist eine.
- */
+
+#if QT_V1
+#define __ColorOnly ColorOnly
+#define __lightGray lightGray
+#define __darkGray darkGray
+#define __white white
+#define __black black
+#define __String QString
+/* gibt an, ob QMap oder die stl-map verwendet wird. */
+#ifndef map_stl
+#define map_stl 1
+#endif
+
+#else // QT 2
+#define __ColorOnly Qt::ColorOnly
+#define __lightGray Qt::lightGray
+#define __darkGray Qt::darkGray
+#define __white Qt::white
+#define __black Qt::black
+#define __String QCString
+#ifndef map_stl
+#define map_stl 0
+#endif
+#endif
+
+
+
+
+#ifndef HAVE_LIBZ
+#define HAVE_LIBZ 0
+#endif
+
+
 #ifdef WIN32
+/* Ob das folgende die beste Lsung fr Windows ist, wei ich nicht.
+   Aber es ist eine. */s
 #ifndef PKGDATADIR
 #define PKGDATADIR (PACKAGE"-"VERSION"\\data")
 #endif
+
+/* Windows: Default hat kein getopt */
+#ifndef HAVE_GETOPT
+#define HAVE_GETOPT 0
 #endif
 
+#else
+/* Nicht Windows: Default hat getopt */
+#ifndef HAVE_GETOPT
+#define HAVE_GETOPT 1
+#endif
+
+#endif
+
+
 
 #endif
 
