@@ -52,13 +52,8 @@ PfadIterator::~PfadIterator() {
   if (mSetzDefault) {
 
     if (mIstAbsolut) {
-      /* Gepfuscht: Wenn ein absoluter Pfad bergeben wird und
-	 gewnscht wird, dass der Default darauf gesetzt wird, dann
-	 hoffen wir einfach, dass der absolute Pfad einer derjenigen
-	 ist, in denen wir suchen wrden. Wenn ja, haben wir den
-	 Default-Pfad. Wenn nein interner Fehler.
-	 Noch mehr gepfuscht: Bisher kommt das nur mit pfad_uebergeben
-	 vor; also braucht nur damit verglichen zu werden. */
+      /* Gepfuscht: Absolute Pfade knnen nicht als default-Pfad gesetzt
+         werden. Einzige Ausnahme: Es handelt sich um den bergebenen Pfad. */
       if (nimmPfad(gLevelDatei) == nimmPfad(mDatei)) {
 	/* Uff, Glck gehabt. */
         gDefaultPfad = pfad_uebergeben;
@@ -153,3 +148,12 @@ __String PfadIterator::pfad() const {
   return r;
 }
 
+
+
+/** Vergisst, welcher Pfad als default gesetzt wurde */
+void PfadIterator::loescheDefault() {
+  gDefaultPfad = -1;
+}
+
+
+
