@@ -30,6 +30,11 @@
     die Datei gar nicht existiert.
     Wenn der bergebene Dateiname schon ein absoluter Pfad ist,
     wird nicht iteriert.
+    Bei setzDefault = true wird der Pfad, in dem die Datei gefunden
+    wurde, als default-Pfad gespeichert, d. h. als der Pfad, in dem
+    spter als erstes gesucht wird. Passiert hauptschlich (nur?)
+    beim Parsen der Haupt-Level-Datei main.ld oder einer bergebenen
+    ld-Datei.
 Verwendung:
   for (PfadIterator pi("pics/miez.xpm"); !test_ex(pi.pfad()); ++pi);
 
@@ -59,6 +64,10 @@ public:
 
   /** Nummer vom Default-Pfad */
   static int gDefaultPfad;
+  
+ public:
+  /** Vergisst, welcher Pfad als default gesetzt wurde */
+  static void loescheDefault();
 };
 
 #endif
