@@ -25,12 +25,11 @@
 #include "spielfeld.h"
 #include "knoten.h"
 #include "aufnahme.h"
+#include "sound.h"
 
 /* Wird nur included fr die Konstanten taste_* */
 #include "prefs.h"
 
-#define papa ((Cuyo *) parent())
-
 
 /***** Konstanten, die was einstellen *****/
 
@@ -187,7 +186,7 @@ void Spielfeld::erzeugTitelbild() {
     mTitelbild.resize(grx * gric, gry * gric);
     {
       QPainter p(&mTitelbild);
-      malUpdate(p);
+      malUpdate(p, true); // true = nicht drauf schauen, ob die Zeit knapp ist
     }
 
   } catch (Fehler fe) {
@@ -225,20 +224,20 @@ void Spielfeld::paintEvent(QPaintEvent * e) {
       /* Schrift drbermalen. In der Mitte, falls es kein Titelbild gibt. */
       malSchrift(p, mTitelbild.isNull());
 
-    } else if (papa->spielPause()) {
+    } else if (Cuyo::gCuyo->spielPause()) {
       /* Spiel steht auf Pause */
 
       p.setBrush(QColor(150, 150, 150));
       p.setPen(NoPen);
       p.drawRect(r);
-      if (papa->mPauseBild) {
-	papa->mPauseBild->malBild(p,
-				  (gric*grx - papa->mPauseBild->getBreite())/2,
-				  (gric*gry - papa->mPauseBild->getHoehe())/2);
+      if (Cuyo::gCuyo->mPauseBild) {
+	Cuyo::gCuyo->mPauseBild->malBild(p,
+		 (gric*grx - Cuyo::gCuyo->mPauseBild->getBreite())/2,
+		 (gric*gry - Cuyo::gCuyo->mPauseBild->getHoehe())/2);
       }
 
       /* Schrift drbermalen. In der Mitte, falls es kein Pausebild gibt. */
-      malSchrift(p, !papa->mPauseBild);
+      malSchrift(p, !Cuyo::gCuyo->mPauseBild);
 
     } else {
       /* Whrend des Spiels... */
@@ -465,7 +464,7 @@ void Spielfeld::spielSchritt() {
   if (mModus == modus_testflopp) {  // (1)
 
     /* Ein guter Zeitpunkt fr's Spielende */
-    if (!papa->spielLaeuft()) {
+    if (!Cuyo::gCuyo->spielLaeuft()) {
 				/* Evtl. Fall platzen lassen */
       if (mFall.existiert()) {
 	mFall.lassPlatzen();
@@ -486,8 +485,9 @@ void Spielfeld::spielSchritt() {
     if (/*mDaten.getTestPlatz() && */!mFall.istEinzel()) {
     
       /* Platzt was? (calcFlopp sendet ggf. auch die Grauen an den Mitspieler) */
-      if (calcFlopp(true)) {
+      if (calcFlopp()) {
 	mModus = modus_flopp;
+        gSound->playSample(mRechterSpieler, sample_explodier);
       }
     }
   }  // Ende von mModus == modus_testflopp (2)
@@ -550,7 +550,7 @@ void Spielfeld::spielSchritt() {
     if (rn != rutschnach_viel) {
 
       /* Aber nur, wenn das Spiel noch luft... */
-      if (papa->spielLaeuft()) {
+      if (Cuyo::gCuyo->spielLaeuft()) {
   		
 	if (mFall.erzeug()) {
         
@@ -567,7 +567,7 @@ void Spielfeld::spielSchritt() {
 	} else {
 	  /* Kein Platz mehr fr neuen Stein => tot */
 	  emit sigTot();
-	  CASSERT(!papa->spielLaeuft());
+	  CASSERT(!Cuyo::gCuyo->spielLaeuft());
 	  /* Allerdings knnen wenigstens die Grauen noch fertig runterfallen.
 	     Also sind wir noch nicht bereit zum stoppen. */
 	}
@@ -659,31 +659,34 @@ void Spielfeld::taste(int t) {
 /** Bewegt das Fall eins nach links */
 void Spielfeld::tasteLinks() {
   mFall.tasteLinks();
+  gSound->playSample(mRechterSpieler, sample_links);
 }
 
 /** Bewegt das Fall eins nach rechts */
 void Spielfeld::tasteRechts() {
   mFall.tasteRechts();
+  gSound->playSample(mRechterSpieler, sample_rechts);
 }
 
 /** Dreht das Fall */
 void Spielfeld::tasteDreh() {
   mFall.tasteDreh();
+  gSound->playSample(mRechterSpieler, sample_dreh);
 }
 
 /** ndert die Fallgeschwindigkeit vom Fall */
 void Spielfeld::tasteFall() {
   mFall.tasteFall();
+  gSound->playSample(mRechterSpieler, sample_fall);
 }
 
 
 
 
-/** berechnet, ob und welche Blops platzen mssen. Bei platzen = false
-    wird nur den Blops die Kettengre mitgeteilt; sonst platzen die Blops
-    evtl., und es werden ggf. auch Graue an den Mitspieler geschickt.
-    liefert true, wenn (bei platzen = true) was passiert ist */
-bool Spielfeld::calcFlopp(bool platzen) {
+/** berechnet, ob und welche Blops platzen mssen. Auerdem
+    werden den Blops die Kettengren mitgeteilt, und Graue
+    und Punkte verteilt */
+bool Spielfeld::calcFlopp() {
   int x, y;
   bool wasPassiert = false;
   /* Die Punkte werden nachher nur gesendet, wenn wirklich was
@@ -719,10 +722,10 @@ bool Spielfeld::calcFlopp(bool platzen) {
 	int neue_pt = calcFloppRec(flopp, x, y,
 				   mDaten.getFeld(x, y).getFarbe(),
 				   1, /* Gre mitteilen... */
-				   platzen && anz >= ld->mPlatzAnzahl, /* Platzen? */
+				   anz >= ld->mPlatzAnzahl, /* Platzen? */
 				   mKettenreaktion || !ld->mGrasBeiKettenreaktion, /* Auch Gras? */
 				   anz);
-	CASSERT(platzen && anz >= ld->mPlatzAnzahl  ||  neue_pt == 0);
+	CASSERT(anz >= ld->mPlatzAnzahl  ||  neue_pt == 0);
 				
 	/* Wenn's Punkte gab, ist wohl auch was geplatzt */
 	if (neue_pt > 0) {
@@ -732,7 +735,6 @@ bool Spielfeld::calcFlopp(bool platzen) {
 	}	
       }
 	
-  CASSERT(!wasPassiert || platzen);
   /* Ist noch was explodiert? */
   if (wasPassiert) {
     /* Dann sende graue */
@@ -824,9 +826,11 @@ int Spielfeld::calcFloppRec(int flopp[grx][gry], int x, int y,
 
 
 /** Ruft malUpdateIntern() auf und malt das interne Bild dann
-    auf p */
-void Spielfeld::malUpdate(QPainter & p) {
-  if (!papa->getInTime()) {
+    auf p.
+    Bei force = true wird nicht darauf geschaut, ob die Zeit gerade
+    knapp ist. */
+void Spielfeld::malUpdate(QPainter & p, bool force /* = false */) {
+  if (!force && !Cuyo::gCuyo->getInTime()) {
     /* Hilfe, die Zeit wird knapp. Grafik ausfallen lassen. */
     return;
   }
@@ -976,7 +980,7 @@ int Spielfeld::getHoehe(){
 
 
 
-/** sollte nur aufgerufen werden, wenn papa->spielLaeuft()
+/** sollte nur aufgerufen werden, wenn Cuyo::gCuyo->spielLaeuft()
     false liefert; liefert true, wenn alle Spiel-Stop-
     Animationen fertig sind; liefert brigens auch true,
     wenn dieser Spieler gar nicht mitspielt */
@@ -1028,18 +1032,10 @@ void Spielfeld::setText(__String t, bool update_event /*= true*/,
       /* Wenn ein Update-Event geschickt werden soll whrend das Spiel
          luft, dann wird das update-Event allein nix bringen, weil
 	 die Grafik auf dem Offscreen-Buffer noch alt ist. Also muss
-	 die in dem Fall auch upgedatet werden. (Update-Events whrend
-	 des Spiels gibt es brigens, wenn ein Fehler whrend des Spiels
-	 passiert und das Spielfeld weiterhin angezeigt werden soll, obwohl
-	 das Spiel abgebrochen wurde. Fr das Spielfeld ist das von der
-	 Grafik her whrend des Spiels.) */
+	 die in dem Fall auch upgedatet werden. */
 	 
-      //if (mModus != modus_keinspiel)
-      //  malUpdateIntern();
-      /* Ach nein, doch nicht. Das Problem ist, dass im Es-ist-ein-Fehler-
-         passiert-Modus Folge-Fehler passieren, wenn man malUpdateIntern()
-	 aufruft. Deshalb wird in diesem Modus die Schrift manuell
-	 drber gemalt, so wie wenn das Spiel beendet wre. */
+      if (mModus != modus_keinspiel)
+        malUpdateIntern();
 	
       update();
     }
@@ -1161,7 +1157,7 @@ void Spielfeld::malSchrift(QPainter & p, bool mitte /*= true*/) {
   if (mText == "")
     return;
     
-  
+
   int align = WordBreak | AlignHCenter |
 	       (mitte ? AlignVCenter : AlignBottom);
   
@@ -1253,7 +1249,7 @@ void Spielfeld::bewegeHetzrand(){
       if (mDaten.getFeldArt(x, hye - 1) != blopart_keins) {
 	/* Hetzrand berdeckt Stein => tot */
 	emit sigTot();
-	CASSERT(!papa->spielLaeuft());
+	CASSERT(!Cuyo::gCuyo->spielLaeuft());
 	/* Evtl. muss auch bei uns noch eine Animation fertig
 	   ablaufen; deshalb noch nicht gleich den mModus auf
 	   modus_warte_auf_stop setzen, sondern
@@ -1479,7 +1475,7 @@ void Spielfeld::gebReihe(int h, int & ret){
     return;
 	
   /* Wenn das Spiel zu Ende gehen soll, keine Reihe mehr rbergeben */
-  if (!papa->spielLaeuft())
+  if (!Cuyo::gCuyo->spielLaeuft())
     return;
 		
   /* Wenn wir schon irgendwie mit einer Reihe beschftigt sind, soll der
@@ -1491,7 +1487,7 @@ void Spielfeld::gebReihe(int h, int & ret){
 		
   /* Sind wir hinreichend hher als der andere? Oder testen wir im
      Debug-Modus das Reihen hin und her schieben? */
-  if (getHoehe() >= h + 2 || papa->mRueberReihenTest) {
+  if (getHoehe() >= h + 2 || Cuyo::gCuyo->mRueberReihenTest) {
 		
     /* Ist unsere unterste Reihe (komplett) verfgbar? */
     ret = bewege_reihe_ja;
