@@ -131,11 +131,10 @@ public:
   /** liefert eine VerbindungsBitliste fr den Blop bei x, y. Bezieht sich
       ggf. auf's Feuer. */
   int getVerbindungen(int x, int y, bool feuer = false) const;
-  /** berechnet, ob und welche Blops platzen mssen. Bei platzen = false
-      wird nur den Blops die Kettengre mitgeteilt; sonst platzen die Blops
-      evtl., und es werden ggf. auch Graue an den Mitspieler geschickt.
-      liefert true, wenn (bei platzen = true) was passiert ist */
-  bool calcFlopp(bool platzen);
+  /** berechnet, ob und welche Blops platzen mssen. Auerdem
+      werden den Blops die Kettengren mitgeteilt, und Graue
+      und Punkte verteilt */
+  bool calcFlopp();
   /** sucht die Zusammenhangskomponente von x, y mit Farbe n.
       Setzt flopp[][] an den entspr. Stellen auf w.
       Aufruf mit w = -1 um rauszufinden, ob genug gleichfarbige beisammen sind;
@@ -152,8 +151,10 @@ public:
 		   int n, int w, bool platzen = false,
 		   bool auch_gras = false, int anz = 0);
   /** Ruft malUpdateIntern() auf und malt das interne Bild dann
-      auf p */
-  void malUpdate(QPainter & p);
+      auf p.
+      Bei force = true wird nicht darauf geschaut, ob die Zeit gerade
+      knapp ist. */
+  void malUpdate(QPainter & p, bool force = false);
   /** Hier findet die Grafik statt: Alles was in den mUpdateXXX-
       Variablen angegeben ist (auch in denen von den Blops selbst),
       wird auf den internen Puffer neu gezeichnet. */
